@@ -2,8 +2,8 @@
 ## Author          : Claus Dethlefsen
 ## Created On      : Sun Dec 02 14:18:04 2001
 ## Last Modified By: Claus Dethlefsen
-## Last Modified On: Tue Dec 10 19:13:39 2002
-## Update Count    : 285
+## Last Modified On: Tue Jul 22 15:31:42 2003
+## Update Count    : 291
 ## Status          : Unknown, Use with caution!
 #######################################################################
 ##
@@ -31,27 +31,12 @@ conditional.cont <- function(A,mu,nu,rho,phi) {
     
     B <- A ## renaming due to compatibility
     
-    if (FALSE) { ## debug info
-        
-        mu <- matrix(mu,ncol=1)
-        
-        cat("conditional.cont(\n")
-        cat("B=\n");print(B)
-        cat("mu=\n");print(mu)
-        cat("nu=\n");print(nu)
-        cat("rho=\n");print(rho)
-        cat("phi=\n");print(phi)
-        cat(")\n")
-    }
-    
     ## calculate conditional probabilities
     ## p. 14 in Bottcher
     ##
     A <- setdiff(1:ncol(phi),B)
     if (length(A)<1) A <- TRUE
     
-    ##cat("A=\n");print(A)
-    
     rho.BlA <- rho + length(A)
     phi.AA.inv <- solve(phi[A,A])
     phi.tmp <- phi[B,A]%*%phi.AA.inv
@@ -64,14 +49,9 @@ conditional.cont <- function(A,mu,nu,rho,phi) {
     tau.inv <- rbind(cbind(tau.BlA.inv.11,t(tau.BlA.inv.12)),
                      cbind(tau.BlA.inv.12,tau.BlA.inv.22)
                      )
+
     tau <- solve(tau.inv)
 
-    ##  cat("=\n")
-    ##  cat("tau=\n");print(tau)
-    ##  cat("phi=\n");print(phi.BlA)
-    ##  cat("mu=\n");print(mu.BlA)
-    ##  cat("rho=\n");print(rho.BlA)
-    
     list(tau=tau,phi=phi.BlA,mu=mu.BlA,rho=rho.BlA)
 }
 
@@ -86,38 +66,14 @@ conditional <- function(A,master,nw) {
     
     ## A is always 1-dimensional
     
-    if (FALSE) {
-        cat("Conditional(",A,")\n")
-        cat("Master:\n")
-        print(master)
-    }
-    
-    ## dette skal ikke matches i nw, men i familien
-    ## family: (sorted) indices of A and its parents
     family <- sort(c(nw$nodes[[A]]$idx,nw$nodes[[A]]$parents))
 
-    ## Example:
-    ##     nw$discrete   <- c(1,4,5,6)
-    ##     nw$continuous <- c(2,3,7)
-    ##     A             <- 4
-    ##     family        <- c(1,3,4,6)
-    ##     intersect(family,nw$discrete) = c(1,4,6)
-    ##     didx <- 2
-    ##     intersect(family,nw$continuous) = c(3)
-    ##     cidx <- c()
-    ##
     ## didx and cidx are used as indices for A in the master
     didx    <- match(A,intersect(family,nw$discrete))
     didx    <- didx[!is.na(didx)]
     cidx    <- match(A,intersect(family,nw$continuous))
     cidx    <- cidx[!is.na(cidx)]
     
-    if (FALSE) {
-        cat("Family=",family,"\n")
-        cat("didx=",didx,"\n")
-        cat("cidx=",cidx,"\n")
-    }
-    
     if (nw$nodes[[A]]$type=="continuous") {
         cond <- list()
         
@@ -132,12 +88,6 @@ conditional <- function(A,master,nw) {
         else {
             for (i in 1:length(master$phi)) {
                 
-                if (FALSE) {
-                    line()
-                    print(i)
-                    print(family)
-                    print(master)
-                }
                 cond[i] <- list(conditional.cont(cidx,
                                                  master$mu[i,],
                                                  master$nu[i],
@@ -149,16 +99,9 @@ conditional <- function(A,master,nw) {
     }
     else if (nw$nodes[[A]]$type=="discrete") {
         
-        if (FALSE) {
-            cat("nw$discrete=",nw$discrete,"\n")
-            cat("match=",match(family,nw$discrete),"\n")
-            cat("master$alpha=",master$alpha,"\n")
-            
-        }
-        
-        cond <- list(list(alpha=master$alpha)) ## 27/2 2002
+        cond <- list(list(alpha=master$alpha)) 
     }
-    else stop("Something happened\n")
+    else stop("Wrong node type in conditional\n")
     
     cond
 }
